@@ -1,6 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 __author__ = "Christian Heider Nielsen"
+__doc__ = r"""
+"""
+__all__ = []
 
 
 # http://localhost:8097
