@@ -16,7 +16,7 @@ __all__ = ["get_sampler"]
 
 
 def get_sampler(seed: Union[RandomState, int] = None) -> RandomState:
-    """ """
+    """description"""
     if isinstance(seed, RandomState):
         return seed
     return numpy.random.RandomState(seed)
