@@ -12,7 +12,7 @@ import torch
 __all__ = ["minmax_to_xywh_torch"]
 
 
-def minmax_to_xywh_torch(boxes: torch.tensor) -> torch.tensor:
+def minmax_to_xywh_torch(boxes: torch.Tensor) -> torch.tensor:
     """
 
     :param boxes:
