@@ -9,58 +9,19 @@ Created on 27/04/2019
 """
 
 from abc import ABCMeta, abstractmethod
-from collections import Counter, deque
+from collections import deque
 
+from draugr.python_utilities.counter_filter import CounterFilter
 from draugr.writers.mixins.scalar_writer_mixin import ScalarWriterMixin
 
 __all__ = ["Writer", "global_writer", "set_global_writer"]
 
-from typing import Any, Iterable, Optional
-
-from warg import is_none_or_zero_or_negative_or_mod_zero
-from warg import drop_unused_kws
+from typing import Any, Optional, Sequence, MutableMapping
 
 
 class Writer(ScalarWriterMixin, metaclass=ABCMeta):
     """description"""
 
-    @drop_unused_kws
-    def __init__(
-        self,
-        *,
-        interval: Optional[int] = 1,
-        filters: Iterable = None,
-        verbose: bool = False
-    ):
-        """
-
-        :param interval:
-        :param filters:
-        :param verbose:"""
-        self._counter = Counter()
-
-        self._interval = interval
-        self.filters = filters
-        self._verbose = verbose
-
-    def filter(self, tag: str) -> bool:
-        """
-
-            returns a boolean  value, true if to be included, False if to be excluded
-
-            tag is in filter if not None
-            and within interval for inclusion
-
-        :param tag:
-        :type tag:
-        :return:
-        :rtype:"""
-        is_in_filters = self.filters is None or tag in self.filters
-        at_interval = is_none_or_zero_or_negative_or_mod_zero(
-            self._interval, self._counter[tag]
-        )
-        return is_in_filters and at_interval
-
     def __enter__(self):
         global GLOBAL_WRITER_STACK, GLOBAL_WRITER
         GLOBAL_WRITER_STACK.appendleft(self)
@@ -95,7 +56,7 @@ class Writer(ScalarWriterMixin, metaclass=ABCMeta):
     def _open(self):
         return self
 
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args: Sequence, **kwargs: MutableMapping):
         self.scalar(*args, *kwargs)
 
 
